@@ -8,9 +8,10 @@ __all__ = (
     "ConfigManager",
 )
 
+import typing
+import warnings
 import weakref
 from collections import defaultdict, deque, namedtuple
-from itertools import chain
 
 from snakeoil import klass, mappings
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
@@ -21,7 +22,6 @@ _section_data = namedtuple("_section_data", ["name", "section"])
 
 
 class _ConfigMapping(mappings.DictMixin):
-
     """Minimal dict-like wrapper returning config sections by type.
 
     Similar to :class:`mappings.LazyValDict` but __getitem__
@@ -32,18 +32,21 @@ class _ConfigMapping(mappings.DictMixin):
     any of them are remote!
     """
 
-    def __init__(self, manager, typename):
+    __slots__ = ("manager", "typename")
+    typename: str
+
+    def __init__(self, manager, typename: str) -> None:
         super().__init__()
         self.manager = manager
         self.typename = typename
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> typing.Any:
         conf = self.manager.collapse_named_section(key, raise_on_missing=False)
         if conf is None or conf.type.name != self.typename:
             raise KeyError(key)
         return conf.instantiate()
 
-    def keys(self):
+    def keys(self) -> typing.Iterator[str]:
         for name in self.manager.sections():
             try:
                 collapsed = self.manager.collapse_named_section(name)
@@ -56,51 +59,25 @@ class _ConfigMapping(mappings.DictMixin):
                 if collapsed.type.name == self.typename:
                     yield name
 
-    def __contains__(self, key):
+    def __contains__(self, key: str) -> bool:
         conf = self.manager.collapse_named_section(key, raise_on_missing=False)
         return conf is not None and conf.type.name == self.typename
 
 
-class _ConfigStack(defaultdict):
-    def __init__(self):
+class _ConfigStack(defaultdict[str, list[typing.Any]]):
+    def __init__(self) -> None:
         super().__init__(list)
 
-    def render_vals(self, manager, key, type_name):
+    def render_value(
+        self, manager, key: str, type_name: str
+    ) -> typing.Optional[typing.Any]:
         for data in self.get(key, ()):
             if key in data.section:
-                yield data.section.render_value(manager, key, type_name)
-
-    def render_val(self, manager, key, type_name):
-        for val in self.render_vals(manager, key, type_name):
-            return val
+                return data.section.render_value(manager, key, type_name)
         return None
 
-    def render_prepends(self, manager, key, type_name, flatten=True):
-        results = []
-        # keep in mind that the sequence we get is a top -> bottom walk of the config
-        # as such for this operation we have to reverse it when building the content-
-        # specifically, reverse the ordering, but not the content of each item.
-        data = []
-        for content in self.render_vals(manager, key, type_name):
-            data.append(content)
-            if content[1]:
-                break
-
-        for prepend, this_content, append in reversed(data):
-            if this_content:
-                results = [this_content]
-            if prepend:
-                results = [prepend] + results
-            if append:
-                results += [append]
-
-        if flatten:
-            results = chain.from_iterable(results)
-        return list(results)
-
 
 class CollapsedConfig:
-
     """A collapsed config section.
 
     :type type: :obj:`basics.ConfigType`
@@ -113,7 +90,19 @@ class CollapsedConfig:
     :ivar name: our section name or C{None} for an anonymous section.
     """
 
-    def __init__(self, type_obj, config, manager, debug=False, default=False):
+    type_obj: basics.ConfigType
+    config: dict[str, typing.Any]
+    debug: bool
+    default: bool
+
+    def __init__(
+        self,
+        type_obj: basics.ConfigType,
+        config: dict[str, typing.Any],
+        manager,
+        debug: bool = False,
+        default: bool = False,
+    ) -> None:
         """Initialize instance vars."""
         # Check if we got all values required to instantiate.
         missing = set(type_obj.required) - set(config)
@@ -136,7 +125,7 @@ class CollapsedConfig:
             manager = weakref.ref(manager)
         self.manager = manager
 
-    def instantiate(self):
+    def instantiate(self) -> typing.Any:
         if self._instance is None:
             try:
                 self._instance = self._instantiate()
@@ -146,7 +135,7 @@ class CollapsedConfig:
                 raise errors.InstantiationError(self.name) from e
         return self._instance
 
-    def _instantiate(self):
+    def _instantiate(self) -> typing.Any:
         """Call our type's callable, cache and return the result.
 
         Calling instantiate more than once will return the cached value.
@@ -231,13 +220,13 @@ class CollapsedConfig:
 
         return self._instance
 
-    def __getstate__(self):
+    def __getstate__(self) -> dict[str, typing.Any]:
         d = self.__dict__.copy()
         # pull actual value from weakref
         d["manager"] = d["manager"]()
         return d
 
-    def __setstate__(self, state):
+    def __setstate__(self, state: dict[str, typing.Any]) -> None:
         self.__dict__ = state.copy()
         # reset weakref
         self.__dict__["manager"] = weakref.ref(self.__dict__["manager"])
@@ -247,41 +236,50 @@ class _ConfigObjMap:
     def __init__(self, manager):
         self._manager = manager
 
-    def __getattr__(self, attr):
+    def __getattr__(self, attr: str) -> typing.Any:
         return _ConfigMapping(self._manager, attr)
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> typing.Any:
         val = getattr(self._manager.objects, key, klass.sentinel)
         if val is None:
             raise KeyError(key)
         return val
 
-    def __getstate__(self):
+    def __getstate__(self) -> dict[str, typing.Any]:
         # Explicitly defined to force pickling to work as expected without
         # trying to pull __getstate__ from _ConfigMapping due to __getattr__.
         return self.__dict__.copy()
 
-    def __setstate__(self, state):
+    def __setstate__(self, state: dict[str, typing.Any]) -> None:
         self.__dict__.update(state)
 
 
 class CompatConfigManager:
-    def __init__(self, manager):
+    """This is a compatibility hack to alias attribute access to the new location
+
+    See commit fa90aff05306fb4935604e64645f2d1d2049233e for when this was introduced.
+
+    This should be removed once consumers are converted in their access."""
+
+    def __init__(self, manager) -> None:
         self._manager = manager
 
-    def __getattr__(self, attr):
+    def __getattr__(self, attr: str) -> typing.Any:
         if attr == "_manager":
             return object.__getattribute__(self, "_manager")
         obj = getattr(self._manager, attr, klass.sentinel)
         if obj is klass.sentinel:
             obj = getattr(self._manager.objects, attr)
+            warnings.warn(
+                f"Access to central objects must be done via '.objects.{attr}' rather than '.{attr}'",
+                stacklevel=2,
+            )
         return obj
 
     __dir__ = klass.DirProxy("_manager")
 
 
 class ConfigManager:
-
     """Combine config type definitions and configuration sections.
 
     Creates instances of a requested type and name by pulling the
@@ -295,7 +293,7 @@ class ConfigManager:
     section with a name starting with "autoload".
     """
 
-    def __init__(self, configs=(), debug=False):
+    def __init__(self, configs=(), debug: bool = False):
         """Initialize.
 
         :type configs: sequence of mappings of string to ConfigSection.
@@ -318,10 +316,10 @@ class ConfigManager:
             return config
         return basics.GeneratedConfigSource(config, "unknown")
 
-    def reload(self):
-        """Reinitialize from the config sources originally passed in.
+    def reload(self) -> None:
+        """Reinitialize from the configured config sources.
 
-        This throws away all cached instances and re-executes autoloads.
+        This throws away all cached instances.
         """
         # "Attribute defined outside __init__"
         # pylint: disable-msg=W0201
@@ -333,23 +331,21 @@ class ConfigManager:
         # force regeneration.
         self._types = klass._uncached_singleton
         for config in self.original_config_sources:
-            self.add_config_source(config)
+            self._integrate_config_source(config)
 
-    def update(self, config):
-        """Reinitialize using an additional supplied config."""
+    def add_config_source(self, config) -> None:
+        """Add the given config source and reload the internal rendering"""
         self.original_config_sources += (config,)
         self.reload()
 
-    def add_config_source(self, config):
-        return self._add_config_source(self._compat_mangle_config(config))
-
-    def _add_config_source(self, config):
+    def _integrate_config_source(self, config) -> None:
         """Pull extra type and config sections from configs and use them.
 
         Things loaded this way are added after already loaded things
         (meaning the config containing the autoload section overrides
         the config(s) added by that section).
         """
+        config = self._compat_mangle_config(config)
         config_data = config.sections()
 
         collision = set(self.rendered_sections)
@@ -395,13 +391,13 @@ class ConfigManager:
             except Exception as e:
                 raise errors.AutoloadInstantiationError(name) from e
             if collapsed.type.name == "configsection":
-                self.add_config_source(instance)
+                self._integrate_config_source(instance)
 
-    def sections(self):
+    def sections(self) -> typing.Iterator[str]:
         """Return an iterator of all section names."""
         return iter(self.sections_lookup.keys())
 
-    def collapse_named_section(self, name, raise_on_missing=True):
+    def collapse_named_section(self, name: str, raise_on_missing: bool = True):
         """Collapse a config by name, possibly returning a cached instance.
 
         @returns: :obj:`CollapsedConfig`.
@@ -435,7 +431,7 @@ class ConfigManager:
         finally:
             self._refs.remove(name)
 
-    def _get_inherited_sections(self, name, sections):
+    def _get_inherited_sections(self, name: str, sections):
         # List of (name, ConfigSection, index) tuples, most specific first.
         slist = [(name, sections)]
 
@@ -445,13 +441,7 @@ class ConfigManager:
             current_conf = section_stack[0]
             if "inherit" not in current_conf:
                 continue
-            prepend, inherits, append = current_conf.render_value(
-                self, "inherit", "list"
-            )
-            if prepend is not None or append is not None:
-                raise errors.ConfigurationError(
-                    "Prepending or appending to the inherit list makes no sense"
-                )
+            inherits = current_conf.render_value(self, "inherit", "list")
             for inherit in inherits:
                 if inherit == current_section:
                     # self-inherit.  Mkae use of section_stack to handle this.
@@ -478,13 +468,13 @@ class ConfigManager:
                     slist.append((inherit, target))
         return [_section_data(name, stack[0]) for (name, stack) in slist]
 
-    def _section_is_inherit_only(self, section):
+    def _section_is_inherit_only(self, section) -> bool:
         if "inherit-only" in section:
             if section.render_value(self, "inherit-only", "bool"):
                 return True
         return False
 
-    def collapse_section(self, sections, _name=None):
+    def collapse_section(self, sections, _name: typing.Optional[str] = None):
         """Collapse a ConfigSection to a :obj:`CollapsedConfig`."""
 
         if self._section_is_inherit_only(sections[0]):
@@ -498,11 +488,11 @@ class ConfigManager:
             for key in data.section.keys():
                 config_stack[key].append(data)
 
-        kls = config_stack.render_val(self, "class", "callable")
+        kls = config_stack.render_value(self, "class", "callable")
         if kls is None:
             raise errors.ConfigurationError("no class specified")
         type_obj = basics.ConfigType(kls)
-        is_default = bool(config_stack.render_val(self, "default", "bool"))
+        is_default = bool(config_stack.render_value(self, "default", "bool"))
 
         for key in ("inherit", "inherit-only", "class", "default"):
             config_stack.pop(key, None)
@@ -517,7 +507,7 @@ class ConfigManager:
         return collapsed
 
     @klass.jit_attr
-    def types(self):
+    def types(self) -> dict[str, dict[str, typing.Any]]:
         type_map = defaultdict(dict)
         for name, sections in self.sections_lookup.items():
             if self._section_is_inherit_only(sections[0]):
@@ -528,7 +518,7 @@ class ConfigManager:
             (k, mappings.ImmutableDict(v)) for k, v in type_map.items()
         )
 
-    def _render_config_stack(self, type_obj, config_stack):
+    def _render_config_stack(self, type_obj, config_stack) -> dict[str, typing.Any]:
         conf = {}
         for key in config_stack:
             typename = type_obj.types.get(key)
@@ -543,14 +533,7 @@ class ConfigManager:
             if typename.startswith("lazy_"):
                 typename = typename[5:]
 
-            if typename.startswith("refs:") or typename in ("list", "str"):
-                result = config_stack.render_prepends(
-                    self, key, typename, flatten=(typename != "str")
-                )
-                if typename == "str":
-                    result = " ".join(result)
-            else:
-                result = config_stack.render_val(self, key, typename)
+            result = config_stack.render_value(self, key, typename)
 
             if is_ref:
                 result = [result]
@@ -582,7 +565,7 @@ class ConfigManager:
 
         return mappings.ImmutableDict(conf)
 
-    def get_default(self, type_name):
+    def get_default(self, type_name: str) -> typing.Optional[typing.Any]:
         """Finds the configuration specified default obj of type_name.
 
         Returns C{None} if no defaults.
