@@ -25,7 +25,8 @@ from collections import defaultdict
 from contextlib import chdir
 from functools import partial
 from itertools import chain
-from os.path import join as pjoin, normpath
+from os.path import join as pjoin
+from os.path import normpath
 from tempfile import TemporaryFile
 
 from snakeoil import data_source, klass
@@ -138,7 +139,7 @@ class ebd:
         self.restrict = pkg.restrict
 
         for x in ("sandbox", "userpriv"):
-            setattr(self, x, self.feat_or_bool(x) and not (x in self.restrict))
+            setattr(self, x, self.feat_or_bool(x) and x not in self.restrict)
         if self.userpriv and os.getuid() != 0:
             self.userpriv = False
 
