@@ -1,6 +1,10 @@
 __all__ = (
-    "null_output", "formatter_output", "file_handle_output",
-    "phase_observer", "repo_observer", "decorate_build_method",
+    "null_output",
+    "formatter_output",
+    "file_handle_output",
+    "phase_observer",
+    "repo_observer",
+    "decorate_build_method",
 )
 
 import threading
@@ -16,24 +20,25 @@ def _convert(msg, args=(), kwds={}):
         if kwds:
             raise TypeError(
                 "both position and optional args cannot be "
-                "supplied: given msg(%r), args(%r), kwds(%r)"
-                % (msg, args, kwds))
+                "supplied: given msg(%r), args(%r), kwds(%r)" % (msg, args, kwds)
+            )
         try:
             return msg % args
         except (ValueError, TypeError) as e:
             raise TypeError(
-                f"observer interpolation error: {e}, msg={msg!r}, args={args!r}")
+                f"observer interpolation error: {e}, msg={msg!r}, args={args!r}"
+            )
     elif kwds:
         try:
             return msg % kwds
         except (KeyError, TypeError, ValueError) as e:
             raise TypeError(
-                f"observer interpolation error: {e}, msg={msg!r}, kwds={kwds!r}")
+                f"observer interpolation error: {e}, msg={msg!r}, kwds={kwds!r}"
+            )
     return msg
 
 
 class null_output:
-
     def warn(self, msg, *args, **kwds):
         pass
 
@@ -54,27 +59,29 @@ class null_output:
 
 
 class formatter_output(null_output):
-
     def __init__(self, out):
         self._out = out
-        self.verbosity = getattr(out, 'verbosity', 0)
+        self.verbosity = getattr(out, "verbosity", 0)
 
     def debug(self, msg, *args, **kwds):
         self._out.write(_convert("debug: " + msg, args, kwds))
 
     def error(self, msg, *args, **kwds):
         prefixes = kwds.pop(
-            'prefixes', (self._out.fg('red'), self._out.bold, ' * ', self._out.reset))
+            "prefixes", (self._out.fg("red"), self._out.bold, " * ", self._out.reset)
+        )
         self._out.write(_convert(msg, args, kwds), prefixes=prefixes)
 
     def info(self, msg, *args, **kwds):
         prefixes = kwds.pop(
-            'prefixes', (self._out.fg('green'), self._out.bold, ' * ', self._out.reset))
+            "prefixes", (self._out.fg("green"), self._out.bold, " * ", self._out.reset)
+        )
         self._out.write(_convert(msg, args, kwds), prefixes=prefixes)
 
     def warn(self, msg, *args, **kwds):
         prefixes = kwds.pop(
-            'prefixes', (self._out.fg('yellow'), self._out.bold, ' * ', self._out.reset))
+            "prefixes", (self._out.fg("yellow"), self._out.bold, " * ", self._out.reset)
+        )
         self._out.write(_convert(msg, args, kwds), prefixes=prefixes)
 
     def write(self, msg, *args, autoline=False, **kwds):
@@ -85,7 +92,6 @@ class formatter_output(null_output):
 
 
 class file_handle_output(formatter_output):
-
     def debug(self, msg, *args, **kwds):
         self._out.write(f"debug: {_convert(msg, args, kwds)}\n")
 
@@ -103,10 +109,9 @@ class file_handle_output(formatter_output):
 
 
 class phase_observer:
-
     def __init__(self, output, debug=False):
         self._output = output
-        self.verbosity = getattr(output, 'verbosity', 0)
+        self.verbosity = getattr(output, "verbosity", 0)
         self._debug = debug
 
     def phase_start(self, phase):
@@ -129,7 +134,6 @@ class phase_observer:
 
 
 class repo_observer(phase_observer):
-
     def trigger_start(self, hook, trigger):
         if self._debug:
             self._output.write(f"hook {hook}: trigger: starting {trigger!r}\n", hook)
@@ -153,11 +157,11 @@ def _mk_observer_proxy(target):
     class foo(target):
         for x in set(dir(target)).difference(dir(object)):
             locals()[x] = pre_curry(_reflection_func, x)
+
     return foo
 
 
 class threadsafe_repo_observer(_mk_observer_proxy(repo_observer)):
-
     def __init__(self, observer):
         self._observer = observer
         self._lock = threading.Lock()
@@ -172,7 +176,7 @@ class threadsafe_repo_observer(_mk_observer_proxy(repo_observer)):
 
 def wrap_build_method(phase, method, self, *args, **kwds):
     disable_observer = kwds.pop("disable_observer", False)
-    if not hasattr(self.observer, 'phase_start') or disable_observer:
+    if not hasattr(self.observer, "phase_start") or disable_observer:
         return method(self, *args, **kwds)
     self.observer.phase_start(phase)
     ret = False
@@ -186,4 +190,5 @@ def wrap_build_method(phase, method, self, *args, **kwds):
 def decorate_build_method(phase):
     def f(func):
         return pre_curry(wrap_build_method, phase, func)
+
     return f
