@@ -15,7 +15,6 @@ from . import errors
 
 
 class base(klass.SlotsPicklingMixin, metaclass=klass.immutable_instance):
-
     built = False
     configurable = False
     _operations = format.operations
@@ -35,12 +34,11 @@ class base(klass.SlotsPicklingMixin, metaclass=klass.immutable_instance):
         return self._operations(domain, self, **kwds)
 
     @property
-    def is_supported(self):
+    def supported(self):
         return True
 
 
 class wrapper(base):
-
     __slots__ = ("_raw_pkg", "_domain")
 
     def operations(self, domain, **kwds):
@@ -83,7 +81,7 @@ class wrapper(base):
     built = klass.alias_attr("_raw_pkg.built")
     versioned_atom = klass.alias_attr("_raw_pkg.versioned_atom")
     unversioned_atom = klass.alias_attr("_raw_pkg.unversioned_atom")
-    is_supported = klass.alias_attr("_raw_pkg.is_supported")
+    supported = klass.alias_attr("_raw_pkg.supported")
 
     def __hash__(self):
         return hash(self._raw_pkg)
@@ -147,7 +145,7 @@ class DynamicGetattrSetter(type):
             # only add slots for new attr's; assume the layer above already slotted
             # if this layer is setting slots.
             class_dict["__slots__"] = tuple(
-                sequences.iter_stable_unique(
+                sequences.unique_stable(
                     itertools.chain(slots, set(new_functions).difference(existing))
                 )
             )
