@@ -4,7 +4,8 @@ import os
 import shutil
 import time
 from itertools import chain
-from os.path import join as pjoin, normpath
+from os.path import join as pjoin
+from os.path import normpath
 
 from snakeoil import compression
 from snakeoil.data_source import local_source
@@ -12,7 +13,6 @@ from snakeoil.osutils import ensure_dirs
 from snakeoil.version import get_version
 
 from .. import __title__
-from ..ebuild import conditionals
 from ..log import logger
 from ..operations import repo as repo_ops
 from .contents import ContentsFile
