@@ -1,11 +1,11 @@
 import pytest
+from snakeoil.iterables import expandable_chain
+from snakeoil.sequences import iflatten_instance
 
 from pkgcore.ebuild import conditionals
 from pkgcore.ebuild.atom import atom
 from pkgcore.ebuild.errors import DepsetParseError
 from pkgcore.restrictions import boolean, packages
-from snakeoil.iterables import expandable_chain
-from snakeoil.sequences import iflatten_instance
 
 
 class base:
@@ -158,7 +158,7 @@ class TestDepSetParsing(base):
             v = depset.split()
         got = list(self.flatten_restricts(base.gen_depset(self, depset)))
         wanted = list(v)
-        assert got == v, "given {s!r}\nexpected {wanted!r} but got {got!r}"
+        assert got == v, f"given {depset!r}\nexpected {wanted!r} but got {got!r}"
 
     @pytest.mark.parametrize("depset", depsets)
     def test_depset_str(self, depset):
