@@ -35,7 +35,7 @@ class TestEAPI:
             # inadequate bash version
             bash_version.return_value = "3.1"
             with pytest.raises(SystemExit) as excinfo:
-                new_eapi = EAPI.register(magic="new", optionals={"bash_compat": "3.2"})
+                _ = EAPI.register(magic="new", optionals={"bash_compat": "3.2"})
             assert (
                 "EAPI 'new' requires >=bash-3.2, system version: 3.1"
                 == excinfo.value.args[0]
