@@ -3,12 +3,13 @@ import os
 import re
 
 import pytest
-from pkgcore.ebuild import atom, repo_objs
-from pkgcore.repository import errors as repo_errors
 from snakeoil.data_source import data_source
 from snakeoil.fileutils import touch
 from snakeoil.mappings import ImmutableDict
 
+from pkgcore.ebuild import atom, repo_objs
+from pkgcore.repository import errors as repo_errors
+
 
 class TestMetadataXml:
     @staticmethod
@@ -134,7 +135,7 @@ class TestMetadataXml:
 
     def test_longdesc(self):
         # empty...
-        assert None == self.get_metadata_xml().longdescription
+        assert self.get_metadata_xml().longdescription is None
         s = """
 I saw the best minds of my generation destroyed by madness, starving
 hysterical naked, dragging themselves throughout the negro streets at dawn
