@@ -1,9 +1,10 @@
 from unittest import mock
 
 import pytest
-from pkgcore.sync import base, cvs
 from snakeoil.process import CommandNotFound
 
+from pkgcore.sync import base, cvs
+
 
 class TestCVSSyncer:
     @pytest.fixture(autouse=True)
@@ -32,13 +33,13 @@ class TestCVSSyncer:
             o = cvs.cvs_syncer(str(self.repo_path), "cvs://dar:module")
             assert o.uri == ":anoncvs:dar"
             assert o.module == "module"
-            assert o.rsh == None
+            assert o.rsh is None
             assert o.env["CVSROOT"] == ":anoncvs:dar"
 
             o = cvs.cvs_syncer(str(self.repo_path), "cvs+pserver://dar:module")
             assert o.uri == ":pserver:dar"
             assert o.module == "module"
-            assert o.rsh == None
+            assert o.rsh is None
             assert o.env["CVSROOT"] == ":pserver:dar"
 
             with mock.patch(
